;; Generated package description from m-buffer.el  -*- no-byte-compile: t -*-
(define-package "m-buffer" "0.16.0.20240302.175529" "List-Oriented, Functional Buffer Manipulation" '((seq "2.14")) :commit "8a51de3366599e7fa52e37b596c9ce226b6f04c5" :url "https://elpa.gnu.org/packages/m-buffer.html" :authors '(("Phillip Lord" . "phillip.lord@russet.org.uk")) :maintainer '("Phillip Lord" . "phillip.lord@russet.rg.uk"))
